# secret-manager
Secret manager for Python

Check Wiki for installation steps
[installation-steps](https://github.com/BLACKBUCK-LABS/secret-manager-python/wiki/Installation-and-distribution-steps)

Know more about it in - 
[secret-manager](https://docs.google.com/document/d/14KTYSOxSezefZ5uJC6wBcSoy3JW6mO6jY_SRmEmR5eI)


